from collections import OrderedDict
from .response import *
import json


class ZohoResponse():

    def __init__(self) -> None:
        self.sales_response = OrderedDict()
        self.response_payload = OrderedDict()
        self.payload = OrderedDict()
        self.replies = []
        self.fulfillment_messages = []
        self.sales_response["fulfillmentMessages"] = self.fulfillment_messages
        self.response_payload["payload"] = self.payload
        self.fulfillment_messages.append(self.response_payload)
        self.payload["platform"] = "ZOHOSALESIQ"
        self.payload["action"] = "reply"

    def __str__(self) -> str:
        return json.dumps(self.sales_response)

    def get_final_response(self):
        self.payload["replies"] = self.replies
        return self.sales_response

    def add(self, response_reply):
        if isinstance(response_reply, TextResponse):
            self.replies.append(response_reply.single_response)
        elif isinstance(response_reply, ImageResponse):
            self.replies.append(response_reply.image_response) 
        elif isinstance(response_reply, SuggestionsChips):
            self.payload["suggestions"] = response_reply.suggestions
        elif isinstance(response_reply, CarouselItems):
            self.replies.append(response_reply.caritems)


from collections import OrderedDict


class TextResponse:
    def __init__(self, display_text) -> None:
        self.single_response = OrderedDict()
        self.single_response["text"] = display_text

class ImageResponse:
    def __init__(self, display_text, display_img) -> None:
        self.image_response = OrderedDict()
        self.image_response["text"] = display_text
        self.image_response["image"] = display_img


class SuggestionsChips:
    def __init__(self, suggestion_chips: list) -> None:
        self.suggestions = []
        for item in suggestion_chips:
            self.suggestions.append(item)
            
class Item:
    
    def __init__(self, title:str, subtitle:str, id: str, image: str, linkAction: str) -> None:
        self.item = OrderedDict()
       
        # elements
        self.item["title"] = title
        self.item["subtitle"] = subtitle
        self.item["id"] = id
        self.item["image"] = image
        # actions
        self.actions = []
        actions = dict()
        actions["label"] = "Ver más",
        actions["name"] = "bookbtn",
        actions["type"] = "url",
        actions["link"] = linkAction
        self.actions.append(actions)
        self.item["actions"] = self.actions
        
class CarouselItems:
    
    def __init__(self, text: str) -> None:
        self.caritems = OrderedDict()
        self.elements = []
        self.caritems["type"] = "multiple-product"
        self.caritems["text"] = text
        self.caritems["elements"] = self.elements
    
    def add(self, element):
        if isinstance(element, Item):
            self.elements.append(element.item)


